"""
Discord.py ThiccStatus Cog implementation
Copyright IsThicc Software 2020-2021
You should have received a copy of the Apache Version 2.0 license 
along with this program. If you didn't, please alert <board@isthicc.dev>
"""

raise SystemExit("This module cannot be imported in it's current state. " 
                 "View more here: https://github.com/IsThicc/ThiccStatusDiscord")
